@@ -17,16 +17,24 @@ If an object is composite, then its components can be queried using the
 """
 iscomposite(x) = length(components(x)) > 0
 
-"Return the components of the composite object `x`."
+"""
+    components(x)
+
+The components of the composite object `x`.
+"""
 components(x) = ()
 
-"Return the number of components of composite object `x`."
+"""
+    ncomponents(x)
+
+The number of components of composite object `x`.
+"""
 ncomponents(x) = length(components(x))
 
 """
     component(x, I...)
 
-Return the component of `x` that corresponds to the given index.
+The component of `x` that corresponds to the given index.
 """
 component(x, I...) = getindex(components(x), I...)
 
